#
# spec file for package bottom
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bottom
Version:        0.10.2~0
Release:        1.1
Summary:        Yet another graphical process/system monitor
License:        Apache-2.0 AND MIT
Group:          System/Monitoring
URL:            https://github.com/ClementTsang/bottom
Source:         %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  rust >= 1.70
BuildRequires:  zstd

%description
A cross-platform graphical process/system monitor with a
customizable interface and a multitude of features.

%prep
%autosetup -p 1 -a 1

%build
cargo build --release --locked %{?_smp_mflags}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%doc sample_configs/*
%{_bindir}/btm

%changelog
* Tue Aug  6 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Adapt service to new cargo vendor version
- Update to version 0.10.2:
  * uptick: 0.10.2 (#1544)
  * bug: fix occasionally wrong run time reported by sysinfo (#1542)
  * docs: update docs and requirements as of 2024-08-05 (#1545)
  * bug: fix default_cpu_entry arg not being used and missing from docs (#1543)
  * bug: fix not updating sysinfo processes correctly (#1541)
  * docs: fix alphabetical ordering of the linux install docs (#1537)
  * docs: update some of the installation docs (#1536)
  * docs: fix incorrect link in all-contributors (#1535)
  * docs: update changelog (#1534)
  * feat: add option to move avg CPU to another row (#1487)
  * other: delete v1.0 schema directory (#1529)
  * uptick: 0.10.1 (#1527)
  * other: add test to catch issues with incorrect long arg names (#1528)
  * bug: fix using clap macro incorrectly, causing broken long help name (#1526)
  * docs: fix invalid flag in docs (#1523)
  * docs: update changelog (#1524)
  * uptick: 0.10.0 (#1510)
  * docs: update docs on filter (#1519)
  * other: clarify config file creation logic/code (#1518)
  * docs: update changelog (#1517)
  * docs: add CosmicHorrorDev as a contributor for code (#1516)
  * other: Add the config path to the error message if unable to create config (#1515)
  * feature: support italic text styling (#1514)
  * change: make table headers bold by default (#1513)
  * feature: support bold text (#1512)
  * feature: support simple colour settings for text fields too (#1511)
  * docs: add the binary name to the title again (#1508)
  * refactor: refactor styling options (#1499)
  * deps: bump deps as of 2024-07-027 (#1507)
  * refactor: remove time as a dependency outside of logging (#1506)
  * uptick: 0.9.7 (#1505)
  * other: remove toolchain, clean up CI (#1504)
  * other: include a toolchain file from now on (#1503)
  * refactor: run clippy after updating to Rust 1.80 (#1502)
  * refactor: remove BottomError (#1498)
  * refactor: migrate data collection and some others away from BottomError (#1497)
  * refactor: convert more errors over (#1496)
  * refactor: out with arg/config error, and make user messages more consistent (#1494)
  * refactor: clean up conversion and crossterm errors (#1493)
  * refactor: error refactoring, part 1 (#1492)
  * deps: bump deps as of 2024-07-03 (#1490)
  * deps: bump root + lock deps as of 2024-06-27 (#1488)
  * deps: bump root deps and lockfile as of 2024-06-19 (#1486)
  * other: add schema test for uncommented default config (#1484)
  * feat: add way to automatically generate new json schemas (#1482)
  * change: change how disk, temp, and net filters in config are set (#1481)
  * uptick: 0.10.0 (#1479)
  * refactor: remove `lib` and move some things around (#1477)
  * bug: fix -V not working and causing Cirrus CI to fail (#1478)
  * refactor: use struct for args instead of builder interface (#1472)
  * deps: update deps as of 2024-05-26 (#1473)
  * Run cargo wix init (#1468)
  * refactor: extract unicode-ellipsis into its own crate (#1465)
  * refactor: some string-related code cleanup/refactor (#1463)
  * docs: add TheSkyentist as a contributor for code (#1461)
  * bug: fix battery table when hiding gaps (#1458)
  * other: comment out some dead code (#1456)
  * docs: add MichalBryxi as a contributor for doc (#1453)
  * docs: Which table goes "flags" under? (#1452)
  * deps: bump lock deps as of 2024-04-28 (#1451)
  * deps: bump deps as of 2024-04-28 (#1450)
  * docs: update some docs about install methods (#1446)
  * deps: bump clap-related dependencies, increase unofficial msrv to 1.74 (#1445)
  * deps: bump dependencies as of 2024-04-10, including sysinfo 0.30.10 (#1444)
  * docs: sort some install methods (#1443)
  * other: update a bunch of argument descriptions and some arg/config names (#1441)
  * docs: add davlgd as a contributor for doc (#1442)
  * docs: add install instructions to Exherbo Linux in README.md (#1440)
  * docs: update changelog for #1436 and #1430 (#1439)
  * docs: add lyuha as a contributor for code, and doc (#1438)
  * feature: Add option to set a position of legend (#1430)
  * change: use sysinfo's swap value for Windows (#1436)
  * deps: bump dependencies as of 2024-03-23 (#1431)
  * docs: bump deps as of 2024-03-23 (#1432)
  * deps: bump sysinfo to =0.30.7 (#1425)
  * deps: downgrade clap and run cargo update to build on 1.70 (#1423)
  * deps: bump root dependencies as of 2024-03-04 (#1422)
  * deps: bump sysinfo to 0.30.6 (#1420)
  * chore(deps): bump mio from 0.8.10 to 0.8.11 (#1421)
  * docs: actually fix numbering for Windows font troubleshooting guide (#1417)
  * docs: fix numbering for Windows font troubleshooting guide (#1416)
  * docs: some clarification (#1415)
  * docs: add john-s-lin as a contributor for doc (#1414)
  * docs: fix broken link to config documentation in README (#1413)
  * other: add process uptime as a default column (#1411)
  * bug: fix uptime calculation for Linux (#1410)
  * deps: update lock dependencies (2024-02-14) (#1409)
  * deps: update root dependencies (2024-02-14) (#1408)
  * other: add v1 schema + versioning + tests (#1407)
  * deps: bump ratatui to 0.26 (#1406)
  * docs: add Freed-Wu as a contributor for code, and doc (#1404)
  * other: add json schema (#1382) (#1394)
  * other: flatten process config struct and clean up help text (#1395)
  * refactor: move some files around in prep for a future options refactor (#1393)
  * refactor: convert layout creation tests back to being unit tests (#1392)
  * deps: bump sysinfo to =0.30.5 (#1390)
  * deps: bump non-root dependencies as of 2024-01-15 (#1387)
  * deps: bump dependencies as of 2024-01-15 (#1386)
  * refactor: simplify some config -> constraints code (#1383)
  * other: fix deploy profile
  * docs: change code font and enable privacy (#1381)
  * add last revision date (#1380)
  * docs: bump mkdocs-material to 0.9.6 (#1379)
  * docs: fix another incorrect heading
  * docs: use consistent wording around command-line options (#1378)
  * refactor: clean up arg code more (#1377)
  * refactor: rearrange/resort args (#1376)
  * refactor: clean up help drawing code (#1374)
  * feature: Add support for bcachefs (#1373)
  * refactor: clean up some more drawing/component code (#1372)
  * refactor: move around some configuration code again (#1371)
  * refactor: move around configuration-related files (#1370)
  * other: update lints (#1369)
  * refactor: restructure canvas file folder structure (#1368)
  * other: quick lint fixes for some warnings (#1367)
  * deps: bump anyhow, clap, and thiserror (#1365)
  * refactor: pull data collection out of nested folder structure (#1364)
  * deps: update ratatui version (#1362)
  * refactor: fix macro formatting in disk data collection code (#1363)
  * refactor: remove once_cell (#1361)
  * refactor: some more cleanups around linux temp code (#1360)
  * other: if in a non-D0 state, short-circuit further logic (#1355)
  * docs: update changelog with #1353 (#1358)
  * chore(deps): bump zerocopy from 0.7.26 to 0.7.31 (#1357)
  * feature: support default selection of average CPU graph (#1353)
  * other: master -> main (#1349)
  * other: add back local time in debug logs (#1346)
  * other: change group -> group_processes for consistency between config and command-line args (#1344)
  * deps: bump dependencies as of 2023-11-27 (#1338)
  * deps: update sysinfo to 0.29.11 (#1337)
  * other: preallocate space for ellipsis (#1336)
  * other: update generated config file (#1335)
  * refactor: iteratively detect ASCII and build string when truncating (#1334)
  * refactor: add fast branch if the string is short enough to not be truncated (#1333)
  * refactor: add fast branch for ascii-only string truncate (#1330)
  * docs: update changelog ordering and some wording (#1328)
  * change changelog heading levels (#1327)
  * refactor: simplify temperature conversion function usage (#1326)
  * change: small gpu proc changes (#1325)
  * feature: Add gpu proc info (#1276)
  * docs: fix typo in process column config (#1323)
  * other: add additional clamping functions on numeric types (#1324)
  * docs: add Android as unsupported but builds in README (#1321)
  * deps: bump toml_edit to 0.21.0 (#1320)
  * docs: bump mike to v2.0.0 (#1318)
  * docs: bump mkdocs-related dependencies to latest (#1317)
  * refactor: clean up some query code and some ascii-only string comparisons (#1316)
  * refactor: comment on convoluted `Filesystem::from_str` code (#1315)
  * chore: fix certain uninlined string format uses (#1310)
  * chore: run spell and grammar checkers
  * bug: fat32 mounts don't show up in macOS (#1314)
  * Chore: Remove un-needed lifetimes in a few calls (#1309)
  * chore: Minor cleanup - remove un-needed ident qualifiers (#1307)
  * bump clap and add nushell/fig completions (#1300)
  * deps: bump sysinfo to =0.29.10 (#1298)
  * docs: bump mkdocs and mkdocs-material versions (#1293)
* Sun Apr  7 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Bump required rust build version
* Tue Aug 29 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correct license to MIT and Apache-2.0
* Sun Aug 27 2023 opensuse-packages@jlk.one
- Update to version 0.9.6~0:
  * uptick: 0.9.6 (#1288)
  * deps: bump dependencies as of 2023-08-26 (#1287)
  * deps: pin serde to 1.0.188 (#1286)
  * docs: update changelog dates
  * ci: pin musl to 1.71.0 for now when building releases (#1282)
  * other: appease clippy after Rust 1.72.0 (#1281)
  * uptick: 0.9.5 (#1280)
  * deps: bump windows to 0.51.1 (#1279)
  * deps: bump dependencies as of 2023-08-18 (#1277)
  * deps: pin serde to <=1.0.171 (#1278)
  * deps: pin sysinfo to 0.29.8 (#1273)
  * deps: bump deps as of 2023-08-08 (#1272)
* Sun Aug 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.6:
  * #1286: Pin serde to 1.0.188 to help with potential cargo install
    issues. Note this version should be fine and not pull in binaries.
* Sun Aug 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.5:
  * #1278: Pin serde to 1.0.171.
* Sun Aug  6 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.9.4:
  Bug Fixes:
  * #1230: Fix core dump if the terminal is closed while bottom is
    open.
  * #1264: Fix ARC usage showing max system memory instead of max
    ARC size.
  Features:
  * #1248: Add I/O counters from ZFS for Linux and FreeBSD.
  Changes:
  * #1236: Hide the battery tab selector if there is only one
    battery detected.
  * #1251: Make the charge meter take the entire width of the
    battery widget.
* Mon Jun 26 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.3:
  * #1216: Fix arguments not being sorted alphabetically.
  * #1219: Fix overflow/underflow in graph timespan zoom.
  * #1221: Support human times for rate.
  * #1206: Add .rpm package generation.
  * #1220: Update documentation for features supporting human times.
* Mon Jun 12 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.2:
  Bug Fixes:
  * #1186: Fix for temperature sensor data gathering on Linux immediately halting if any method failed.
  * #1191: Fix ntfs3 mounts not being counted as a physical drive type.
  * #1195: Fix battery health being incorrectly reported on M1 macOS.
  * #1188: Don't fail fast with temperature sensor name generation on Linux.
  Features:
  * #1172: Support human times for time_delta and default_time_value.
  * #1187: Use better names for duplicate temp sensors on Linux.
  * #1188: Also check /sys/devices/platform/coretemp.* for temp sensors on Linux.
  Other:
  * #1199: bottom should build on aarch64-linux-android with features disabled.
* Sun May 14 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * #1148: Fix Gruvbox colour string being invalid when cache usage
    is enabled.
* Thu May 11 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Add memory build constraint
* Wed May 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  Bug Fixes:
  * #1021: Fix selected text background colour being wrong if only
    the foreground colour was set.
  * #1037: Fix is_list_ignored accepting all results if set to false
  * #1064: Disk name/mount filter now doesn't always show all
    entries if one filter wasn't set.
  * #1064: macOS disk I/O is potentially working now.
  * #597: Resolve RUSTSEC-2021-0119 by removing heim.
  Features:
  * #1016: Add support for displaying process usernames on Windows
  * #1022: Support three-character hex colour strings for styling.
  * #1024: Support FreeBSD temperature sensors based on hw.temperature.
  * #1063: Add buffer and cache memory tracking.
  * #1106: Add current battery charging state.
  * #1115: Add customizable process columns to config file.
  * #801: Add optional process time column and querying.
  Changes:
  * #1025: Officially support M1 macOS.
  * #1035: Migrate away from heim for CPU information.
  * #1036: Migrate away from heim for memory information; bottom
    will now try to use MemAvailable on Linux to determine used memory.
  * #1041: Migrate away from heim for network information.
  * #1064: Migrate away from heim for storage information.
  * #812: Fully remove heim from bottom.
  * #1075: Update how drives are named in Windows.
  * #1106: Rename battery consumption field to rate.
  Other:
  * #1008: Fix clap 3 deprecation warnings.
  * #1044: Re-enable ZFS feature.
  * #1100: Speed up first draw and first data collection.
  * #1107: Update to clap v4.
  * #1111: Update to regex 1.8.0, supporting more escapable characters
    and named captures.
* Mon Jan 23 2023 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.8.0:
  * Bug Fixes
    + Update help menu for disk and temperature widgets with
    sorting support.
    + Fix time graph labels not being styled.
  * Features
    + Split usage into both usage percentage and usage value.
  * Changes
    + Hide battery duration section if the value is unknown. Also
    update shortened text.
    + Automatically hide the battery widget if no batteries are
    found but --battery is enabled.
* Fri Jan  6 2023 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.7.1:
  * Bug Fixes
    + Fixes invalid sorting order for disk usage percentage
    + Partially fix battery text getting cut off in small windows
    + Fix CPU widget's 'all' label being missing on small sizes
* Sun Jan  1 2023 Jan-Luca Kiok <me@jlk.one>
- Add build dependency to zstd compression tool
* Sun Jan  1 2023 Jan-Luca Kiok <me@jlk.one>
- Apply current rust service template
- Change source compress algorithm
- Use cargo test for check stage
- Update to version 0.7.0:
  * Bug Fixes
    + Fix building in Rust beta 1.61 due to `as_ref()` calls
    causing type inference issues.
    + Fix clicking on empty space in tables selecting the very last
    entry of a list in some cases.
    + Fix panic if battery feature was disabled during compilation.
    + Fix bottom keeping devices awake in certain scenarios
    + Use alternative method of getting parent PID in some cases on
    macOS devices to avoid needing root access.
    + Fix possible gaps with widget layout spacing.
    + Fix search scrolling with wider Unicode characters.
  * Changes
    + Add some colour to `-h`/`--help` as part of updating to clap
    3.0.
    + Add ARM musl binary build tasks.
    + Add more human friendly temperature sensor names for Linux
    + Add macOS M1, FreeBSD 12, and FreeBSD 13 binary build tasks.
    + Improve CPU usage by optimizing draw logic of charts and
    tables.
  * Features
    + Add support for NVIDIA GPU temperature sensors
    + Add a check for whether bottom is being run in a terminal.
    + Add FreeBSD support
    + Add half page scrolling with `ctrl-u` and `ctrl-d`
    + Add ZFS ARC support
    + Add GPU memory support for NVIDIA GPUs
    + Update sysinfo to support M1 macOS temperature sensors.
    + Add CLI options for GPU memory
    + Add page up/page down support for the help screen
    + Make temperature widget sortable.
    + Make disk widget sortable.
    + Add pasting to the search bar.
    + Add custom retention periods for data.
    + Add non-normalized CPU usage to processes
    + Add an option to expand the default widget on startup
  * Other
    + Fix dead links in docs
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Fri Mar 18 2022 Jan-Luca Kiok <me@jlk.one>
- Package version appropriate deps
* Fri Mar 18 2022 Jan-Luca Kiok <me@jlk.one>
- Update to 0.6.8:
  * Add PgUp/PgDown keybind support to scroll up and down a page in
    a table
  * Fix bug where the program would stall in an infinite loop if
    the width of the terminal was too small
  * Fix a bug where the number of CPUs is never refreshed
  * Update sysinfo
- Strip binary
- Require cargo version 1.58 at least for binary stripping on cargo
  build
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.6:
  * Address RUSTSEC-2020-0071
  * Fixes process_command breaking process widget sorting
  * Fix process CPU calculation if /proc/stat CPU line has less values than expected
  * Remove duplicate guest time in process CPU calculation
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.4
  * Small update to fix a bug and being slightly clearer on the
    network legend unit.
- Update to version 0.6.3
  * Small release with some bug fixes and a change in how we
    calculate Linux memory usage.
- Update to version 0.6.2
  Features
  * Add F9 key as an alternative process kill key.
  Bug Fixes
  * Fixes two bugs causing the battery widget colours and mouse
    events to be broken.
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.1
  * Fine-grained kill signals - bottom defaulted to kill -15, but
    now, on Unix-based systems, you can directly choose which kill
    signal you want.
  * You can disable this feature if you want with the
  - -disable_advanced_kill flag or config option, which will
    instead revert to the older style with just two options.
  * Scroll position indicator using --show_table_scroll_position.
  * Added Nord colour schemes. This can be enabled either in the
    config file or command line with color=nord or color=nord-light.
  * Add Ctrl-w and Ctrl-h shortcuts in search in order to delete a
    word or a character respectively.
  * Added mouse support for sorting process columns:
  * Added users as a column in the process widget.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.7
  * Fixes incorrect colours being used the CPU widget in basic
    mode.
  * Fixes hide_table_gap not working in the battery widget.
  * Fixes the sorting arrow disappearing in proc widget under
    some cases.
  * Fixes basic mode failing to report CPUs if there are less than
    4 entries to report.
- Update to version 0.5.6
  * Fixed temperature sensors not working at all on non-Linux
    platforms.
- Update to version 0.5.5
  * Fixed CPU graph colours not matching the legend in the "all"
    state.
- Update to version 0.5.4
  Changes
  * Removed the --debug option for now.
  Bug Fixes
  * Fixes a performance regression causing high memory and CPU
    usage over time.
  * Fixes process states not showing.
* Sat Nov 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.3
  * Fixes custom battery colour levels being inverted.
- Update to version 0.5.2
  * Fixes hide_avg_cpu being inverted in config files.
- Update to version 0.5.1
  * Patch for some bugs that were spotted in the 0.5.0 release.
- Update to version 0.5.0
  Features
  * Adaptive network graphs: the network widget's y-axis will now
    adjust based on your current usage.
  * Mouse support for tables and moving to widgets.
  * The ability to hide specific temperature and disk entries
    via config.
  * Added a tree mode, you can access this with the t key.
  * A simple indicator for when data updating is frozen.
  * Built-in colour themes.
  Changes
  * Updated help descriptions, added auto-complete generation.
  * Changed how we do battery theming. We now only set high,
    medium, and low colours and we deal with the ratios.
  Bug Fixes
  * Fixes a bug where you could move down in the process widget
    even if the process widget search was closed.
  * Add labels to Linux temperature values.
  * Implements sorting by count. It previously did absolutely
    nothing.
  * Fix being able to cause an index out-of-bounds by resizing to
    a smaller terminal just after the program got the terminal
    size, but right before the terminal started drawing.
  * Fixed not clearing screen before drawing, which caused issues
    for some environments.
  * Fix highlighted entries being stuck in another colour when the
    widget is not selected.
  * Expanding a widget no longer overrides the widget/dialog title
    colour.
  * Fixed process names occasionally showing up as truncated, due
    to only using /proc//stat as our data source.
  * Fixed missing thread termination steps as well as improper
    polling causing blocking in input thread.
  * Fixed the CPU basic widget showing incorrect data due to an
    incorrect offset when displaying the data.
  * Fixed an incorrect offset affecting the CPU colour when
    scrolling.
  * Fixed spacing problems in basic CPU mode.
  * Fixed an incorrect offset affecting the graph CPU colour
    mismatching the legend.
  * Removes an accidental extra comma in one of the headers in the
    disk widget.
  * Removes the automatically generated CPU colours method.
* Sun Aug 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.7
  * Just a single bug fix, where searching by command name was
    broken.
- Update to version 0.4.6
  * Minor update, with some bug fixes, changes, and new features.
    Most of the work done was refactoring and updating old, weird
    code.
  Features
  * Allow using P to toggle between the processes' base name and
    the processes' full name
  * Added sorting capabilities for any column. Using s will open
    up a menu allowing you to select which column you want to sort
    by.
  * Added I to invert the current process sort.
  * Added the ability to toggle between mem%% and actual memory
    values by using %% in the process widget:
  * Support searching processes by state (i.e. state=sleeping).
  * Added WASD as an alternative method to moving between widgets.
  * Made e also escape expanded widgets (so e expands, then
    pressing e again will shrink the widget, like if you had pressed
    ESC).
  Changes
  * Dropped MSRV (for now), mainly supporting stable and newer
    versions of Rust.
  Bug fixes
  * Fixed bug in basic mode where the battery widget was placed
    incorrectly.
  * Fixed a bug caused by hitting Enter when a process kill fails,
    breaking future process kills.
  * Fix bug caused by incorrectly reading the /proc/{pid}/stats file.
- Update to version 0.4.5
  * Minor update to match needing to update on crates.io.  No changes.
* Mon Jul  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.4
  Features
  * Added process states to the processes widget.
  Bug Fixes
  * Fixed a bug where bottom would incorrectly read the wrong
    values to calculate the read/write columns for processes
    in Linux.
  * Fixed a bug where OR operations in the process query wouldn't
    properly for some cases.
  * Improved process query overall
  Changes
  * Showing average CPU is now on by default. Disable it via flag.
  * Removed CPU filtering. I didn't like it and had planned on
    rolling out this change with an alternative, more usable CPU
    widget system. Note, if you liked it, let me know, it's easy
    to add back in as an option but for now, I ripped it out since
    it was causing more headaches.
  * show_disabled_data flag and option are also removed as they
    are now irrelevant.
  * Made the CPU entry you're scrolling over highlight even when
    you're not on the widget.
* Fri May 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.3
  * Minor update to update a dependency to avoid an overflow.
* Tue May 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.2
  Changes
  * Automatically hide time axis labels if the widget gets too
    small.
  * Automatically hide table gap if the widget gets too small.
  Bugs
  * The <Space> character can be used as an "AND" again (properly)
    in queries. For example:
  * Fixed an issue where if the drive I/O label didn't match any
    disk, the entire disk widget would display no results.
  * Display SWAP and MEM legends even if the total amount is 0 to
    avoid a weird blank spot in the legend.
* Sat May  9 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.4.1
